pub struct CommandPolicyBinding {
pub field: String,
pub kind: CommandBindingKind,
}Expand description
Declarative mapping from an input field to command policy checks.
Fields
field: StringDot path to the argument field containing command data.
kind: CommandBindingKindRole of the command data in the request.
Implementations
Sourceimpl CommandPolicyBinding
impl CommandPolicyBinding
Sourcepub fn command(field: impl Into<String>) -> CommandPolicyBinding
pub fn command(field: impl Into<String>) -> CommandPolicyBinding
Declare a command string field.
Sourcepub fn argv(field: impl Into<String>) -> CommandPolicyBinding
pub fn argv(field: impl Into<String>) -> CommandPolicyBinding
Declare an argv array field.
Sourcepub fn cwd(field: impl Into<String>) -> CommandPolicyBinding
pub fn cwd(field: impl Into<String>) -> CommandPolicyBinding
Declare a command working-directory field.
Sourcepub fn env(field: impl Into<String>) -> CommandPolicyBinding
pub fn env(field: impl Into<String>) -> CommandPolicyBinding
Declare a command environment object field.