pub struct StaticDiagnosticsProvider { /* private fields */ }Expand description
Static diagnostics provider used by tests and eval fixtures.
Implementations
Sourceimpl StaticDiagnosticsProvider
impl StaticDiagnosticsProvider
Sourcepub fn new(diagnostics: Vec<DiagnosticItem>) -> Self
pub fn new(diagnostics: Vec<DiagnosticItem>) -> Self
Create a provider that returns a deterministic diagnostics list.
Sourcepub fn with_availability(
diagnostics: Vec<DiagnosticItem>,
available: bool,
) -> Self
pub fn with_availability( diagnostics: Vec<DiagnosticItem>, available: bool, ) -> Self
Create a provider with explicit availability.